@@ -214,6 +214,13 @@ from asposewordscloud.models.split_document_result import SplitDocumentResult
 from asposewordscloud.models.stat_data_response import StatDataResponse
 from asposewordscloud.models.storage_file import StorageFile
 from asposewordscloud.models.story_child_nodes import StoryChildNodes
+from asposewordscloud.models.structured_document_tag import StructuredDocumentTag
+from asposewordscloud.models.structured_document_tag_collection import StructuredDocumentTagCollection
+from asposewordscloud.models.structured_document_tag_insert import StructuredDocumentTagInsert
+from asposewordscloud.models.structured_document_tag_list_item import StructuredDocumentTagListItem
+from asposewordscloud.models.structured_document_tag_response import StructuredDocumentTagResponse
+from asposewordscloud.models.structured_document_tags_response import StructuredDocumentTagsResponse
+from asposewordscloud.models.structured_document_tag_update import StructuredDocumentTagUpdate
 from asposewordscloud.models.style import Style
 from asposewordscloud.models.style_apply import StyleApply
 from asposewordscloud.models.style_copy import StyleCopy
