@@ -75,6 +75,8 @@ from asposewordscloud.models.requests.delete_run_request import DeleteRunRequest
 from asposewordscloud.models.requests.delete_run_online_request import DeleteRunOnlineRequest
 from asposewordscloud.models.requests.delete_section_request import DeleteSectionRequest
 from asposewordscloud.models.requests.delete_section_online_request import DeleteSectionOnlineRequest
+from asposewordscloud.models.requests.delete_structured_document_tag_request import DeleteStructuredDocumentTagRequest
+from asposewordscloud.models.requests.delete_structured_document_tag_online_request import DeleteStructuredDocumentTagOnlineRequest
 from asposewordscloud.models.requests.delete_table_request import DeleteTableRequest
 from asposewordscloud.models.requests.delete_table_cell_request import DeleteTableCellRequest
 from asposewordscloud.models.requests.delete_table_cell_online_request import DeleteTableCellOnlineRequest
@@ -180,6 +182,10 @@ from asposewordscloud.models.requests.get_section_page_setup_request import GetS
 from asposewordscloud.models.requests.get_section_page_setup_online_request import GetSectionPageSetupOnlineRequest
 from asposewordscloud.models.requests.get_sections_request import GetSectionsRequest
 from asposewordscloud.models.requests.get_sections_online_request import GetSectionsOnlineRequest
+from asposewordscloud.models.requests.get_structured_document_tag_request import GetStructuredDocumentTagRequest
+from asposewordscloud.models.requests.get_structured_document_tag_online_request import GetStructuredDocumentTagOnlineRequest
+from asposewordscloud.models.requests.get_structured_document_tags_request import GetStructuredDocumentTagsRequest
+from asposewordscloud.models.requests.get_structured_document_tags_online_request import GetStructuredDocumentTagsOnlineRequest
 from asposewordscloud.models.requests.get_style_request import GetStyleRequest
 from asposewordscloud.models.requests.get_style_from_document_element_request import GetStyleFromDocumentElementRequest
 from asposewordscloud.models.requests.get_style_from_document_element_online_request import GetStyleFromDocumentElementOnlineRequest
@@ -226,6 +232,8 @@ from asposewordscloud.models.requests.insert_paragraph_request import InsertPara
 from asposewordscloud.models.requests.insert_paragraph_online_request import InsertParagraphOnlineRequest
 from asposewordscloud.models.requests.insert_run_request import InsertRunRequest
 from asposewordscloud.models.requests.insert_run_online_request import InsertRunOnlineRequest
+from asposewordscloud.models.requests.insert_structured_document_tag_request import InsertStructuredDocumentTagRequest
+from asposewordscloud.models.requests.insert_structured_document_tag_online_request import InsertStructuredDocumentTagOnlineRequest
 from asposewordscloud.models.requests.insert_style_request import InsertStyleRequest
 from asposewordscloud.models.requests.insert_style_online_request import InsertStyleOnlineRequest
 from asposewordscloud.models.requests.insert_table_request import InsertTableRequest
@@ -309,6 +317,8 @@ from asposewordscloud.models.requests.update_run_font_online_request import Upda
 from asposewordscloud.models.requests.update_run_online_request import UpdateRunOnlineRequest
 from asposewordscloud.models.requests.update_section_page_setup_request import UpdateSectionPageSetupRequest
 from asposewordscloud.models.requests.update_section_page_setup_online_request import UpdateSectionPageSetupOnlineRequest
+from asposewordscloud.models.requests.update_structured_document_tag_request import UpdateStructuredDocumentTagRequest
+from asposewordscloud.models.requests.update_structured_document_tag_online_request import UpdateStructuredDocumentTagOnlineRequest
 from asposewordscloud.models.requests.update_style_request import UpdateStyleRequest
 from asposewordscloud.models.requests.update_style_online_request import UpdateStyleOnlineRequest
 from asposewordscloud.models.requests.update_table_cell_format_request import UpdateTableCellFormatRequest
