@@ -24,6 +24,7 @@ from asposewordscloud.models.responses.insert_or_update_paragraph_tab_stop_onlin
 from asposewordscloud.models.responses.insert_page_numbers_online_response import InsertPageNumbersOnlineResponse
 from asposewordscloud.models.responses.insert_paragraph_online_response import InsertParagraphOnlineResponse
 from asposewordscloud.models.responses.insert_run_online_response import InsertRunOnlineResponse
+from asposewordscloud.models.responses.insert_structured_document_tag_online_response import InsertStructuredDocumentTagOnlineResponse
 from asposewordscloud.models.responses.insert_style_online_response import InsertStyleOnlineResponse
 from asposewordscloud.models.responses.insert_table_cell_online_response import InsertTableCellOnlineResponse
 from asposewordscloud.models.responses.insert_table_online_response import InsertTableOnlineResponse
@@ -56,6 +57,7 @@ from asposewordscloud.models.responses.update_paragraph_list_format_online_respo
 from asposewordscloud.models.responses.update_run_font_online_response import UpdateRunFontOnlineResponse
 from asposewordscloud.models.responses.update_run_online_response import UpdateRunOnlineResponse
 from asposewordscloud.models.responses.update_section_page_setup_online_response import UpdateSectionPageSetupOnlineResponse
+from asposewordscloud.models.responses.update_structured_document_tag_online_response import UpdateStructuredDocumentTagOnlineResponse
 from asposewordscloud.models.responses.update_style_online_response import UpdateStyleOnlineResponse
 from asposewordscloud.models.responses.update_table_cell_format_online_response import UpdateTableCellFormatOnlineResponse
 from asposewordscloud.models.responses.update_table_properties_online_response import UpdateTablePropertiesOnlineResponse
